/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.hpp'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../diffpdf-v2.1.3.1/mainwindow.hpp"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MainWindow_t {
    QByteArrayData data[37];
    char stringdata0[468];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MainWindow_t qt_meta_stringdata_MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 10), // "MainWindow"
QT_MOC_LITERAL(1, 11, 8), // "setFile1"
QT_MOC_LITERAL(2, 20, 0), // ""
QT_MOC_LITERAL(3, 21, 8), // "filename"
QT_MOC_LITERAL(4, 30, 8), // "setFile2"
QT_MOC_LITERAL(5, 39, 9), // "setFiles1"
QT_MOC_LITERAL(6, 49, 9), // "filenames"
QT_MOC_LITERAL(7, 59, 9), // "setFiles2"
QT_MOC_LITERAL(8, 69, 7), // "compare"
QT_MOC_LITERAL(9, 77, 7), // "options"
QT_MOC_LITERAL(10, 85, 4), // "save"
QT_MOC_LITERAL(11, 90, 5), // "about"
QT_MOC_LITERAL(12, 96, 4), // "help"
QT_MOC_LITERAL(13, 101, 10), // "initialize"
QT_MOC_LITERAL(14, 112, 9), // "filename1"
QT_MOC_LITERAL(15, 122, 9), // "filename2"
QT_MOC_LITERAL(16, 132, 8), // "updateUi"
QT_MOC_LITERAL(17, 141, 11), // "updateViews"
QT_MOC_LITERAL(18, 153, 5), // "index"
QT_MOC_LITERAL(19, 159, 26), // "controlDockLocationChanged"
QT_MOC_LITERAL(20, 186, 18), // "Qt::DockWidgetArea"
QT_MOC_LITERAL(21, 205, 4), // "area"
QT_MOC_LITERAL(22, 210, 25), // "actionDockLocationChanged"
QT_MOC_LITERAL(23, 236, 25), // "zoningDockLocationChanged"
QT_MOC_LITERAL(24, 262, 26), // "marginsDockLocationChanged"
QT_MOC_LITERAL(25, 289, 22), // "controlTopLevelChanged"
QT_MOC_LITERAL(26, 312, 8), // "floating"
QT_MOC_LITERAL(27, 321, 21), // "actionTopLevelChanged"
QT_MOC_LITERAL(28, 343, 21), // "zoningTopLevelChanged"
QT_MOC_LITERAL(29, 365, 22), // "marginsTopLevelChanged"
QT_MOC_LITERAL(30, 388, 18), // "logTopLevelChanged"
QT_MOC_LITERAL(31, 407, 13), // "previousPages"
QT_MOC_LITERAL(32, 421, 9), // "nextPages"
QT_MOC_LITERAL(33, 431, 9), // "showZones"
QT_MOC_LITERAL(34, 441, 11), // "showMargins"
QT_MOC_LITERAL(35, 453, 10), // "setAMargin"
QT_MOC_LITERAL(36, 464, 3) // "pos"

    },
    "MainWindow\0setFile1\0\0filename\0setFile2\0"
    "setFiles1\0filenames\0setFiles2\0compare\0"
    "options\0save\0about\0help\0initialize\0"
    "filename1\0filename2\0updateUi\0updateViews\0"
    "index\0controlDockLocationChanged\0"
    "Qt::DockWidgetArea\0area\0"
    "actionDockLocationChanged\0"
    "zoningDockLocationChanged\0"
    "marginsDockLocationChanged\0"
    "controlTopLevelChanged\0floating\0"
    "actionTopLevelChanged\0zoningTopLevelChanged\0"
    "marginsTopLevelChanged\0logTopLevelChanged\0"
    "previousPages\0nextPages\0showZones\0"
    "showMargins\0setAMargin\0pos"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MainWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      29,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,  159,    2, 0x08 /* Private */,
       1,    0,  162,    2, 0x28 /* Private | MethodCloned */,
       4,    1,  163,    2, 0x08 /* Private */,
       4,    0,  166,    2, 0x28 /* Private | MethodCloned */,
       5,    1,  167,    2, 0x08 /* Private */,
       7,    1,  170,    2, 0x08 /* Private */,
       8,    0,  173,    2, 0x08 /* Private */,
       9,    0,  174,    2, 0x08 /* Private */,
      10,    0,  175,    2, 0x08 /* Private */,
      11,    0,  176,    2, 0x08 /* Private */,
      12,    0,  177,    2, 0x08 /* Private */,
      13,    2,  178,    2, 0x08 /* Private */,
      16,    0,  183,    2, 0x08 /* Private */,
      17,    1,  184,    2, 0x08 /* Private */,
      17,    0,  187,    2, 0x28 /* Private | MethodCloned */,
      19,    1,  188,    2, 0x08 /* Private */,
      22,    1,  191,    2, 0x08 /* Private */,
      23,    1,  194,    2, 0x08 /* Private */,
      24,    1,  197,    2, 0x08 /* Private */,
      25,    1,  200,    2, 0x08 /* Private */,
      27,    1,  203,    2, 0x08 /* Private */,
      28,    1,  206,    2, 0x08 /* Private */,
      29,    1,  209,    2, 0x08 /* Private */,
      30,    1,  212,    2, 0x08 /* Private */,
      31,    0,  215,    2, 0x08 /* Private */,
      32,    0,  216,    2, 0x08 /* Private */,
      33,    0,  217,    2, 0x08 /* Private */,
      34,    0,  218,    2, 0x08 /* Private */,
      35,    1,  219,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QStringList,    6,
    QMetaType::Void, QMetaType::QStringList,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   14,   15,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   18,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 20,   21,
    QMetaType::Void, 0x80000000 | 20,   21,
    QMetaType::Void, 0x80000000 | 20,   21,
    QMetaType::Void, 0x80000000 | 20,   21,
    QMetaType::Void, QMetaType::Bool,   26,
    QMetaType::Void, QMetaType::Bool,   26,
    QMetaType::Void, QMetaType::Bool,   26,
    QMetaType::Void, QMetaType::Bool,   26,
    QMetaType::Void, QMetaType::Bool,   26,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,   36,

       0        // eod
};

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MainWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setFile1((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 1: _t->setFile1(); break;
        case 2: _t->setFile2((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 3: _t->setFile2(); break;
        case 4: _t->setFiles1((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 5: _t->setFiles2((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 6: _t->compare(); break;
        case 7: _t->options(); break;
        case 8: _t->save(); break;
        case 9: _t->about(); break;
        case 10: _t->help(); break;
        case 11: _t->initialize((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 12: _t->updateUi(); break;
        case 13: _t->updateViews((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->updateViews(); break;
        case 15: _t->controlDockLocationChanged((*reinterpret_cast< Qt::DockWidgetArea(*)>(_a[1]))); break;
        case 16: _t->actionDockLocationChanged((*reinterpret_cast< Qt::DockWidgetArea(*)>(_a[1]))); break;
        case 17: _t->zoningDockLocationChanged((*reinterpret_cast< Qt::DockWidgetArea(*)>(_a[1]))); break;
        case 18: _t->marginsDockLocationChanged((*reinterpret_cast< Qt::DockWidgetArea(*)>(_a[1]))); break;
        case 19: _t->controlTopLevelChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 20: _t->actionTopLevelChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: _t->zoningTopLevelChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 22: _t->marginsTopLevelChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 23: _t->logTopLevelChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 24: _t->previousPages(); break;
        case 25: _t->nextPages(); break;
        case 26: _t->showZones(); break;
        case 27: _t->showMargins(); break;
        case 28: _t->setAMargin((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_meta_stringdata_MainWindow.data,
    qt_meta_data_MainWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MainWindow.stringdata0))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 29;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
